@@ -1,12 +1,13 @@
+use mira::error::MiraError;
 use mira::loader;
 use mira::mem::{zeroed_vec, from_cstring};
 use mira::vulkan::*;
 use const_cstr::*;
 
-fn main() {
+fn main() -> Result<(), MiraError> {
     let enumerate_instance_extensions:PFN_vkEnumerateInstanceExtensionProperties;
     enumerate_instance_extensions = unsafe {
-        loader::instance(std::ptr::null_mut(), const_cstr!("vkEnumerateInstanceExtensionProperties"))
+        loader::instance(std::ptr::null_mut(), const_cstr!("vkEnumerateInstanceExtensionProperties"))?
     };
 
     let mut count:u32 = 0;
@@ -24,4 +25,6 @@ fn main() {
 
         println!("extension #{} - {}", extension.0, str);
     }
+
+    Ok(())
 }
